@@ -9,7 +9,7 @@ library(alfred)
 df <- get_fred_series("INDPRO", "indpro")
 
 ## ------------------------------------------------------------------------
-df
+head(df)
 
 ## ---- fig.show = "hold"--------------------------------------------------
 library(ggplot2)
@@ -21,7 +21,7 @@ df_vintages <-
   get_alfred_series("GDPC1", "rgdp",
                     observation_start = "2007-05-31",
                     realtime_start = "2008-05-31", realtime_end = "2009-03-30")
-df_vintages
+head(df_vintages)
 
 ## ---- fig.show = "hold", fig.width = 6-----------------------------------
 library(ggplot2)
